termui_tinpot library

Classes

CellQuantizer
ColorMath
Utility class for perceptual color math using the DIN99d color space.
QuantizeResult
SymbolCandidate
SymbolMap
TermuiTinpot

Functions

parseBackgroundColor(String? input) int?
Parses a hex background color string into a 32-bit ARGB integer.

Typedefs

TinpotOutputCell = ({int bgColorArgb, String character, int fgColorArgb})